@@ -1,10 +1,9 @@
-#include <cmath>
+#include "gen_lat_func.h"
 #include <R.h>
 #include <Rinternals.h>
 #include <Rmath.h>
-#include "gen_lat_func.h"
 extern "C" {
-#include "FL.h"
+  #include "FL_vit.h"
 }
 
 
@@ -15,11 +14,7 @@ extern "C" {
 /*************************************************************************/
 
 /*************************************************************************/
-//The function CopyAtoB() copies matrix A to matrix B.
-//Arguments:
-//pA - Pointer to matrix A.
-//pB - Pointer to matrix B.
-//nel - Total number of elements.
+//Useful for keeping track of estimates over iterations.
 /*************************************************************************/
 void CopyAtoB(double* pA, double* pB, int nel) {
 
@@ -30,13 +25,7 @@ void CopyAtoB(double* pA, double* pB, int nel) {
 }
 
 /*************************************************************************/
-//The function SqColSums() takes a matrix of reals and returns the column
-//sums of the squared matrix. 
-//Arguments:
-//pmat - Pointer to a matrix.
-//pmatSqCS - Pointer to the array of column sums.
-//nr - Number of rows of matrix.
-//nc - Number of cols of matrix.
+//Mainly used in estimating the Theta matrix.
 /*************************************************************************/
 void SqColSums(double* pmat, double* pmatSqCS, int nr, int nc) {
 
@@ -50,13 +39,7 @@ void SqColSums(double* pmat, double* pmatSqCS, int nr, int nc) {
 }
 
 /*************************************************************************/
-//The function SqRowSums() takes a matrix of reals and returns the row
-//sums of the squared matrix.
-//Arguments:
-//pmat - Pointer to a matrix.
-//pmatSqRS - Pointer to the array of row sums.
-//nr - Number of rows of matrix.
-//nc - Number of cols of matrix.
+//Mainly used in estimating the Beta matrix.
 /*************************************************************************/
 void SqRowSums(double* pmat, double* pmatSqRS, int nr, int nc) {
 
@@ -70,11 +53,7 @@ void SqRowSums(double* pmat, double* pmatSqRS, int nr, int nc) {
 }
 
 /*************************************************************************/
-//The function SqTotSum() takes a matrix of reals and returns the total
-//sum of the elements of the squared matrix. 
-//Arguments:
-//pmat - Pointer to a matrix.
-//nel - Total number of elements.
+//Used in calculating matrix error and checking for zero matrices.
 /*************************************************************************/
 double SqTotSum(double* pmat, int nel) {
 
@@ -87,15 +66,7 @@ double SqTotSum(double* pmat, int nel) {
 }
 
 /*************************************************************************/
-//The function MatErr() takes pointers to two matrices, poldMat and
-//pnewMat, and calculates the square root of the Frobeniuus norm of the
-//difference divided by the square root of the Frobenius norm of oldMat.
-//Arguments:
-//pnewMat - Pointer to the new matrix.
-//poldMat - Pointer to the old matrix.
-//nel - Total number of elements.
-//thresh - The threshold for convergence.  If oldMat=0 and newMat=0,
-//function returns 0.  If only oldMat=0, function returns thresh+1.
+//Used for checking convergence over iterations.
 /*************************************************************************/
 double MatErr(double* pnewMat, double* poldMat, int nel, double thresh) {
 
@@ -112,7 +83,7 @@ double MatErr(double* pnewMat, double* poldMat, int nel, double thresh) {
       num += (pnewMat[i]-poldMat[i])*(pnewMat[i]-poldMat[i]);
       den += poldMat[i]*poldMat[i];
     }
-    res = sqrt(num/den);
+    res = std::sqrt(num/den);
   }
 
   return(res);
@@ -120,16 +91,13 @@ double MatErr(double* pnewMat, double* poldMat, int nel, double thresh) {
 }
 
 /*************************************************************************/
-//The fuction SoftThresh() applies soft threshholds val by thresh.
-//Arguments:
-//val - What we want to soft threshold.
-//thresh - Thet value we are soft thresholding by.
+//Used in estimating Beta.
 /*************************************************************************/
 double SoftThresh(double val, double thresh) {
   double t1;
   t1 = sign(val);
   double t2;
-  t2 = ((fabs(val) - thresh) >= 0) ? fabs(val) - thresh : 0.0;
+  t2 = ((std::fabs(val) - thresh) >= 0) ? std::fabs(val) - thresh : 0.0;
   return(t1*t2);
 }
 
@@ -141,16 +109,7 @@ double SoftThresh(double val, double thresh) {
 /*************************************************************************/
 
 /*************************************************************************/
-//The function MakeTldY() creates the the vector of \tilde{Y}_j.
-//Arguments:
-//pnewY - Poimter to array of \tilde{Y}_j.
-//pY - Pointer to the original data matrix.
-//pB - Pointer to the current Beta matrix.
-//pnewT - Pointer to the current Theta matrix, to be updated.
-//j - The current row index of Theta.
-//S - Number of columns of Y.
-//L - Number of rows of Y.
-//J - Number of columns of Beta.
+//This quantity is required in estimating the Theta matrix.
 /*************************************************************************/
 void MakeTldY(double* ptldY, double* pY, double* pB, double* pnewT,
 	      int j, int S, int L, int J) {
@@ -164,17 +123,7 @@ void MakeTldY(double* ptldY, double* pY, double* pB, double* pnewT,
 }
 
 /*************************************************************************/
-//The function MakeGrvY() creates the the vector of \grave{Y}_j.
-//Arguments:
-//pgrvY - Pointer to array of \grave{Y}_j.
-//pY - Pointer to the original data matrix.
-//pT - Pointer to the current Theta matrix.
-//pnewB - Pointer to the current Beta matrix, to be updated.
-//pTSqRS - Pointer to the array of row sums of Theta^2.
-//j - The current row index of Theta.
-//S - Number of columns of Y.
-//L - Number of rows of Y.
-//J - Number of columns of Beta.
+//This quantity is required in estimating the Beta matrix.
 /*************************************************************************/
 void MakeGrvY(double* pgrvY, double* pY, double* pT, double* pnewB,
 	      double* pTSqRS, int j, int S, int L, int J) {
@@ -189,16 +138,7 @@ void MakeGrvY(double* pgrvY, double* pY, double* pT, double* pnewB,
 }
 
 /*************************************************************************/
-//The function BTljsSum() calculates \sum_{k\ne j}\beta_{lk}\theta_{ks}.
-//Arguments:
-//pB - Pointer to Beta.
-//pT - Pointer to Theta.
-//s - Column of Theta.
-//l - Row of Beta.
-//j - Row of Theta (or column of Beta) not included in sum.
-//S - Number of columns of Y.
-//L - Number of rows of Y.
-//J - Number of columns of Beta.
+//This quantity is used in the MakeTldY() and MakeGrvY() functions.
 /*************************************************************************/
 double BTljsSum(double* pB, double* pT, int s, int l, int j, int S, int L,
 		int J) {
@@ -213,18 +153,8 @@ double BTljsSum(double* pB, double* pT, int s, int l, int j, int S, int L,
 }
 
 /*************************************************************************/
-//The function BC() estimates the value of the Beta matrix for a given
-//Theta matrix.  Arguments:
-//pnewB - The current Beta which will become updated.
-//pY - Pointer to the data matrix.
-//pT - Pointer to the current Theta matrix.
-//rlam1 - Lambda_1.
-//rlam2 - Lambda_2.
-//rthresh - The error threshold for determining convergence.
-//imaxiter - The maximum number of iterations.
-//S - Number of samples.
-//L - Number of chromosomal locations.
-//J - Number of latent features.
+//The estimated Beta matrix after either convergence or the iteration limit
+//is reached.
 /*************************************************************************/
 void BC(double* pnewB, double* pY, double* pT, double rlam1, double rlam2,
 	double rthresh, int imaxiter, int S, int L, int J) {
@@ -252,17 +182,8 @@ void BC(double* pnewB, double* pY, double* pT, double rlam1, double rlam2,
 }
 
 /************************************************************************/
-//The function UpdateBC() updates Beta.
-//Arguments:
-//pnewB - Pointer to the current Beta which will be updated.
-//pY - Pointer to the original data matrix.
-//pT - Pointer to the current Theta matrix.
-//pTSqRS - A pointer to the array of row sums of Theta^2.
-//rlam1 - Lambda_1.
-//rlam2 - Lambda_2.
-//S - Number of samples.
-//L - Number of chromosomal locations.
-//J - Number of latent features.
+//Updates the Beta matrix for each iteration.  Uses the Viterbi algorithm
+//for solving the FLSA developed by Nick Johnson.
 /************************************************************************/
 void UpdateBC(double* pnewB, double* pY, double* pT, double* pTSqRS,
 	      double rlam1, double rlam2, int S, int L, int J) {
@@ -311,17 +232,8 @@ void UpdateBC(double* pnewB, double* pY, double* pT, double* pTSqRS,
 }
 
 /***********************************************************************/
-//The function TLatL2C estimates the value of the Theta matrix for a
-//given Beta matrix and returns the number of iterations.  Arguments:
-//pnewT - The current Theta which will be updated. 
-//pY - The data matrix.
-//pB - The current Beta matrix.
-//rthresh - The error threshold for determining convergence.
-//imaxiter - The maximum number of iterations.
-//rsT -  The constraint on the L2 sum of each row of Theta.
-//S - Number of samples.
-//L - Number of chromosomal locations.
-//J - Number of latent features.
+//The estimated Theta matrix after either convergence or the iteration
+//limit is reached.
 /***********************************************************************/
 int TLatL2C(double* pnewT, double* pY, double* pB, double rthresh,
 	     int imaxiter, double rsT, int S, int L, int J) {
@@ -350,16 +262,7 @@ int TLatL2C(double* pnewT, double* pY, double* pB, double rthresh,
 }
 
 /***********************************************************************/
-//The function UpdateTLatL2C() updates Theta.
-//Arguments:
-//pnewT - The matrix which will become the updated Theta.
-//pY - Pointer to the original data matrix.
-//pB - Pointer to the current Beta matrix.
-//pBSqCS - A pointer to the array of column sums of Beta^2.
-//rsT - The constraint on the L2 sum of each row of Theta.
-//S - Number of samples.
-//L - Number of chromosomal locations.
-//J - Number of latent features.
+////Updates the Theta matrix for each iteration.
 /***********************************************************************/
 void UpdateTLatL2C(double* pnewT, double* pY, double* pB,
 		   double* pBSqCS, double rsT, int S, int L, int J) {
@@ -373,19 +276,19 @@ void UpdateTLatL2C(double* pnewT, double* pY, double* pB,
     for (int s = 0; s < S; s++) {
       tldYSqS += ptldY[s]*ptldY[s];
     }
-    tldYnrm = sqrt(tldYSqS);
+    tldYnrm = std::sqrt(tldYSqS);
 
     if (pBSqCS[j]==0) {
       for (int s = 0; s < S; s++) {
 	pnewT[j+J*s] = 0.0;
       }
-    } else if (tldYnrm <= sqrt(rsT)*(pBSqCS[j])) {
+    } else if (tldYnrm <= std::sqrt(rsT)*(pBSqCS[j])) {
       for (int s = 0; s < S; s++) {
 	pnewT[j+J*s] = ptldY[s]/pBSqCS[j];
       }
     } else {
       for (int s = 0; s < S; s++) {
-	pnewT[j+J*s] = sqrt(rsT)*ptldY[s]/tldYnrm;
+	pnewT[j+J*s] = std::sqrt(rsT)*ptldY[s]/tldYnrm;
       }
     }
 
@@ -394,14 +297,7 @@ void UpdateTLatL2C(double* pnewT, double* pY, double* pB,
 }
 
 /************************************************************************/
-//The function LatRSS() calculates the residual sum of squares.
-//Arguments:
-//pY - Pointer to the original data matrix.
-//pB - Pointer to the current Beta matrix.
-//pT - Pointer to the current Theta matrix.
-//S - Number of samples.
-//L - Number of chromosomal locations.
-//J - Number of latent features.
+//Mainly used for calculating the PVE.
 /************************************************************************/
 double LatRSS(double* pY, double* pB, double* pT, int S, int L, int J) {
 
@@ -425,13 +321,7 @@ double LatRSS(double* pY, double* pB, double* pT, int S, int L, int J) {
 }
 
 /************************************************************************/
-//The function LatBIC() calculates the BIC.
-//Arguments:
-//rss - The residual sum of squares.
-//pB - Pointer to the current Beta matrix.
-//S - Number of samples.
-//L - Number of chromosomal locations.
-//J - Number of latent features.
+//Used for finding the optimal values of lambda1 and lambda2.
 /************************************************************************/
 double LatBIC(double rss, double* pB, int S, int L, int J) {
 
@@ -454,7 +344,7 @@ double LatBIC(double rss, double* pB, int S, int L, int J) {
     delete [] pBcol;
   }
 
-  bic = log(S*L*1.0)*nparms + S*L*1.0*log(rss/(S*L));
+  bic = std::log(S*L*1.0)*nparms + S*L*1.0*std::log(rss/(S*L));
 
   return(bic);
 
